# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgDisReinvest.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgDisReinvest(object):
    def setupUi(self, wdgDisReinvest):
        wdgDisReinvest.setObjectName("wdgDisReinvest")
        wdgDisReinvest.resize(818, 585)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/tools-wizard.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        wdgDisReinvest.setWindowIcon(icon)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(wdgDisReinvest)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lblTitulo = QtWidgets.QLabel(wdgDisReinvest)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lblTitulo.setFont(font)
        self.lblTitulo.setStyleSheet("color: rgb(0, 128, 0);")
        self.lblTitulo.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitulo.setObjectName("lblTitulo")
        self.verticalLayout_3.addWidget(self.lblTitulo)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem)
        self.grp = QtWidgets.QGroupBox(wdgDisReinvest)
        self.grp.setTitle("")
        self.grp.setObjectName("grp")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.grp)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.radRe = QtWidgets.QRadioButton(self.grp)
        self.radRe.setChecked(True)
        self.radRe.setObjectName("radRe")
        self.horizontalLayout.addWidget(self.radRe)
        self.radDes = QtWidgets.QRadioButton(self.grp)
        self.radDes.setChecked(False)
        self.radDes.setObjectName("radDes")
        self.horizontalLayout.addWidget(self.radDes)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.groupBox = QtWidgets.QGroupBox(self.grp)
        self.groupBox.setObjectName("groupBox")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.groupBox)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.lblSimulacion = QtWidgets.QLabel(self.groupBox)
        self.lblSimulacion.setObjectName("lblSimulacion")
        self.horizontalLayout_12.addWidget(self.lblSimulacion)
        self.txtSimulacion = myQLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtSimulacion.sizePolicy().hasHeightForWidth())
        self.txtSimulacion.setSizePolicy(sizePolicy)
        self.txtSimulacion.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtSimulacion.setObjectName("txtSimulacion")
        self.horizontalLayout_12.addWidget(self.txtSimulacion)
        self.verticalLayout_2.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.lblValor = QtWidgets.QLabel(self.groupBox)
        self.lblValor.setObjectName("lblValor")
        self.horizontalLayout_5.addWidget(self.lblValor)
        self.txtValorAccion = myQLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtValorAccion.sizePolicy().hasHeightForWidth())
        self.txtValorAccion.setSizePolicy(sizePolicy)
        self.txtValorAccion.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtValorAccion.setObjectName("txtValorAccion")
        self.horizontalLayout_5.addWidget(self.txtValorAccion)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_4.addWidget(self.label_3)
        self.txtComision = myQLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtComision.sizePolicy().hasHeightForWidth())
        self.txtComision.setSizePolicy(sizePolicy)
        self.txtComision.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtComision.setObjectName("txtComision")
        self.horizontalLayout_4.addWidget(self.txtComision)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_11.addWidget(self.label_5)
        self.txtAcciones = myQLineEdit(self.groupBox)
        self.txtAcciones.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtAcciones.sizePolicy().hasHeightForWidth())
        self.txtAcciones.setSizePolicy(sizePolicy)
        self.txtAcciones.setText("")
        self.txtAcciones.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtAcciones.setObjectName("txtAcciones")
        self.horizontalLayout_11.addWidget(self.txtAcciones)
        self.verticalLayout_2.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_3.addWidget(self.label_2)
        self.txtImporte = myQLineEdit(self.groupBox)
        self.txtImporte.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtImporte.sizePolicy().hasHeightForWidth())
        self.txtImporte.setSizePolicy(sizePolicy)
        self.txtImporte.setText("")
        self.txtImporte.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtImporte.setObjectName("txtImporte")
        self.horizontalLayout_3.addWidget(self.txtImporte)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_6.addLayout(self.verticalLayout_2)
        self.verticalLayout.addWidget(self.groupBox)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.cmdOrder = QtWidgets.QPushButton(self.grp)
        self.cmdOrder.setEnabled(False)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdOrder.setIcon(icon1)
        self.cmdOrder.setObjectName("cmdOrder")
        self.horizontalLayout_2.addWidget(self.cmdOrder)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.cmd = QtWidgets.QPushButton(self.grp)
        self.cmd.setIcon(icon)
        self.cmd.setObjectName("cmd")
        self.horizontalLayout_2.addWidget(self.cmd)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_7.addLayout(self.verticalLayout)
        self.horizontalLayout_8.addWidget(self.grp)
        self.cmdGraph = QtWidgets.QToolButton(wdgDisReinvest)
        self.cmdGraph.setEnabled(False)
        self.cmdGraph.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/report.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdGraph.setIcon(icon2)
        self.cmdGraph.setIconSize(QtCore.QSize(64, 64))
        self.cmdGraph.setObjectName("cmdGraph")
        self.horizontalLayout_8.addWidget(self.cmdGraph)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem2)
        self.verticalLayout_3.addLayout(self.horizontalLayout_8)
        self.tabAB = QtWidgets.QTabWidget(wdgDisReinvest)
        self.tabAB.setTabPosition(QtWidgets.QTabWidget.West)
        self.tabAB.setObjectName("tabAB")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.tab_5)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.tabOpAcHi = QtWidgets.QTabWidget(self.tab_5)
        self.tabOpAcHi.setObjectName("tabOpAcHi")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.tab_9)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.tblOperaciones = myQTableWidget(self.tab_9)
        self.tblOperaciones.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblOperaciones.setAlternatingRowColors(True)
        self.tblOperaciones.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tblOperaciones.setObjectName("tblOperaciones")
        self.tblOperaciones.setColumnCount(8)
        self.tblOperaciones.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblOperaciones.setHorizontalHeaderItem(7, item)
        self.tblOperaciones.verticalHeader().setVisible(False)
        self.horizontalLayout_17.addWidget(self.tblOperaciones)
        self.tabOpAcHi.addTab(self.tab_9, "")
        self.Situac_2 = QtWidgets.QWidget()
        self.Situac_2.setObjectName("Situac_2")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.Situac_2)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.tblInvestmentsActualDespues = myQTableWidget(self.Situac_2)
        self.tblInvestmentsActualDespues.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblInvestmentsActualDespues.setAlternatingRowColors(True)
        self.tblInvestmentsActualDespues.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tblInvestmentsActualDespues.setObjectName("tblInvestmentsActualDespues")
        self.tblInvestmentsActualDespues.setColumnCount(9)
        self.tblInvestmentsActualDespues.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespues.setHorizontalHeaderItem(8, item)
        self.tblInvestmentsActualDespues.verticalHeader().setVisible(False)
        self.horizontalLayout_15.addWidget(self.tblInvestmentsActualDespues)
        self.tabOpAcHi.addTab(self.Situac_2, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.tab_8)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.tblInvestmentsHistoricas = myQTableWidget(self.tab_8)
        self.tblInvestmentsHistoricas.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblInvestmentsHistoricas.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tblInvestmentsHistoricas.setAlternatingRowColors(True)
        self.tblInvestmentsHistoricas.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tblInvestmentsHistoricas.setObjectName("tblInvestmentsHistoricas")
        self.tblInvestmentsHistoricas.setColumnCount(11)
        self.tblInvestmentsHistoricas.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(9, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsHistoricas.setHorizontalHeaderItem(10, item)
        self.tblInvestmentsHistoricas.verticalHeader().setVisible(False)
        self.horizontalLayout_16.addWidget(self.tblInvestmentsHistoricas)
        self.tabOpAcHi.addTab(self.tab_8, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.tblGainsAfter = myQTableWidget(self.tab_2)
        self.tblGainsAfter.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tblGainsAfter.setAlternatingRowColors(True)
        self.tblGainsAfter.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblGainsAfter.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblGainsAfter.setObjectName("tblGainsAfter")
        self.tblGainsAfter.setColumnCount(3)
        self.tblGainsAfter.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblGainsAfter.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblGainsAfter.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblGainsAfter.setHorizontalHeaderItem(2, item)
        self.tblGainsAfter.verticalHeader().setVisible(False)
        self.horizontalLayout_10.addWidget(self.tblGainsAfter)
        self.tabOpAcHi.addTab(self.tab_2, "")
        self.horizontalLayout_18.addWidget(self.tabOpAcHi)
        self.tabAB.addTab(self.tab_5, "")
        self.tab_11 = QtWidgets.QWidget()
        self.tab_11.setObjectName("tab_11")
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout(self.tab_11)
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.tabResultados_3 = QtWidgets.QTabWidget(self.tab_11)
        self.tabResultados_3.setObjectName("tabResultados_3")
        self.tab_12 = QtWidgets.QWidget()
        self.tab_12.setObjectName("tab_12")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout(self.tab_12)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.tblInvestmentsActualDespuesAt = myQTableWidget(self.tab_12)
        self.tblInvestmentsActualDespuesAt.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblInvestmentsActualDespuesAt.setAlternatingRowColors(True)
        self.tblInvestmentsActualDespuesAt.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tblInvestmentsActualDespuesAt.setObjectName("tblInvestmentsActualDespuesAt")
        self.tblInvestmentsActualDespuesAt.setColumnCount(9)
        self.tblInvestmentsActualDespuesAt.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualDespuesAt.setHorizontalHeaderItem(8, item)
        self.tblInvestmentsActualDespuesAt.verticalHeader().setVisible(False)
        self.horizontalLayout_23.addWidget(self.tblInvestmentsActualDespuesAt)
        self.tabResultados_3.addTab(self.tab_12, "")
        self.horizontalLayout_25.addWidget(self.tabResultados_3)
        self.tabAB.addTab(self.tab_11, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.tab_3)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.tabResultados_2 = QtWidgets.QTabWidget(self.tab_3)
        self.tabResultados_2.setObjectName("tabResultados_2")
        self.tab_7 = QtWidgets.QWidget()
        self.tab_7.setObjectName("tab_7")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.tab_7)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.tblInvestmentsActualAntesAt = myQTableWidget(self.tab_7)
        self.tblInvestmentsActualAntesAt.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblInvestmentsActualAntesAt.setAlternatingRowColors(True)
        self.tblInvestmentsActualAntesAt.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tblInvestmentsActualAntesAt.setObjectName("tblInvestmentsActualAntesAt")
        self.tblInvestmentsActualAntesAt.setColumnCount(9)
        self.tblInvestmentsActualAntesAt.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntesAt.setHorizontalHeaderItem(8, item)
        self.tblInvestmentsActualAntesAt.verticalHeader().setVisible(False)
        self.horizontalLayout_20.addWidget(self.tblInvestmentsActualAntesAt)
        self.tabResultados_2.addTab(self.tab_7, "")
        self.horizontalLayout_22.addWidget(self.tabResultados_2)
        self.tabAB.addTab(self.tab_3, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.tab_6)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.tabResultados = QtWidgets.QTabWidget(self.tab_6)
        self.tabResultados.setObjectName("tabResultados")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.tab_4)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.tblInvestmentsActualAntes = myQTableWidget(self.tab_4)
        self.tblInvestmentsActualAntes.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblInvestmentsActualAntes.setAlternatingRowColors(True)
        self.tblInvestmentsActualAntes.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.tblInvestmentsActualAntes.setObjectName("tblInvestmentsActualAntes")
        self.tblInvestmentsActualAntes.setColumnCount(9)
        self.tblInvestmentsActualAntes.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestmentsActualAntes.setHorizontalHeaderItem(8, item)
        self.tblInvestmentsActualAntes.verticalHeader().setVisible(False)
        self.horizontalLayout_13.addWidget(self.tblInvestmentsActualAntes)
        self.tabResultados.addTab(self.tab_4, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.tab)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.tblGainsBefore = myQTableWidget(self.tab)
        self.tblGainsBefore.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tblGainsBefore.setAlternatingRowColors(True)
        self.tblGainsBefore.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblGainsBefore.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblGainsBefore.setObjectName("tblGainsBefore")
        self.tblGainsBefore.setColumnCount(3)
        self.tblGainsBefore.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblGainsBefore.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblGainsBefore.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblGainsBefore.setHorizontalHeaderItem(2, item)
        self.tblGainsBefore.verticalHeader().setVisible(False)
        self.horizontalLayout_9.addWidget(self.tblGainsBefore)
        self.tabResultados.addTab(self.tab, "")
        self.horizontalLayout_19.addWidget(self.tabResultados)
        self.tabAB.addTab(self.tab_6, "")
        self.verticalLayout_3.addWidget(self.tabAB)
        self.horizontalLayout_14.addLayout(self.verticalLayout_3)

        self.retranslateUi(wdgDisReinvest)
        self.tabAB.setCurrentIndex(3)
        self.tabOpAcHi.setCurrentIndex(1)
        self.tabResultados_3.setCurrentIndex(0)
        self.tabResultados_2.setCurrentIndex(0)
        self.tabResultados.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(wdgDisReinvest)

    def retranslateUi(self, wdgDisReinvest):
        _translate = QtCore.QCoreApplication.translate
        self.radRe.setText(_translate("wdgDisReinvest", "Reinvest simulation"))
        self.radDes.setText(_translate("wdgDisReinvest", "Disinvest simulation"))
        self.groupBox.setTitle(_translate("wdgDisReinvest", "Operation data"))
        self.txtSimulacion.setText(_translate("wdgDisReinvest", "1000"))
        self.txtValorAccion.setText(_translate("wdgDisReinvest", "0"))
        self.label_3.setText(_translate("wdgDisReinvest", "Bank comission"))
        self.txtComision.setText(_translate("wdgDisReinvest", "10"))
        self.label_5.setText(_translate("wdgDisReinvest", "Shares number"))
        self.label_2.setText(_translate("wdgDisReinvest", "Amount"))
        self.cmdOrder.setText(_translate("wdgDisReinvest", "Add order annotations"))
        self.cmd.setText(_translate("wdgDisReinvest", "Make simulation"))
        self.cmdGraph.setToolTip(_translate("wdgDisReinvest", "Show operations in a graph"))
        item = self.tblOperaciones.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "Id"))
        item = self.tblOperaciones.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Date"))
        item = self.tblOperaciones.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Operation type"))
        item = self.tblOperaciones.horizontalHeaderItem(3)
        item.setText(_translate("wdgDisReinvest", "Shares"))
        item = self.tblOperaciones.horizontalHeaderItem(4)
        item.setText(_translate("wdgDisReinvest", "Price"))
        item = self.tblOperaciones.horizontalHeaderItem(5)
        item.setText(_translate("wdgDisReinvest", "Balance"))
        item = self.tblOperaciones.horizontalHeaderItem(6)
        item.setText(_translate("wdgDisReinvest", "Comission"))
        item = self.tblOperaciones.horizontalHeaderItem(7)
        item.setText(_translate("wdgDisReinvest", "Taxes"))
        self.tabOpAcHi.setTabText(self.tabOpAcHi.indexOf(self.tab_9), _translate("wdgDisReinvest", "Investment operations"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "Date"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Shares"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Price"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(3)
        item.setText(_translate("wdgDisReinvest", "Balance"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(4)
        item.setText(_translate("wdgDisReinvest", "Pending"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(5)
        item.setText(_translate("wdgDisReinvest", "% Annual"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(6)
        item.setText(_translate("wdgDisReinvest", "% APR"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(7)
        item.setText(_translate("wdgDisReinvest", "% Total"))
        item = self.tblInvestmentsActualDespues.horizontalHeaderItem(8)
        item.setText(_translate("wdgDisReinvest", "Benchmark"))
        self.tabOpAcHi.setTabText(self.tabOpAcHi.indexOf(self.Situac_2), _translate("wdgDisReinvest", "Investment current state"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "Date"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Years"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Investment"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(3)
        item.setText(_translate("wdgDisReinvest", "Operation type"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(4)
        item.setText(_translate("wdgDisReinvest", "Initial balance"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(5)
        item.setText(_translate("wdgDisReinvest", "Final balance"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(6)
        item.setText(_translate("wdgDisReinvest", "Gross"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(7)
        item.setText(_translate("wdgDisReinvest", "Comissions"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(8)
        item.setText(_translate("wdgDisReinvest", "Taxes"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(9)
        item.setText(_translate("wdgDisReinvest", "Net"))
        item = self.tblInvestmentsHistoricas.horizontalHeaderItem(10)
        item.setText(_translate("wdgDisReinvest", "% Total"))
        self.tabOpAcHi.setTabText(self.tabOpAcHi.indexOf(self.tab_8), _translate("wdgDisReinvest", "Historical operations"))
        item = self.tblGainsAfter.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "% Gains"))
        item = self.tblGainsAfter.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Price"))
        item = self.tblGainsAfter.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Gains"))
        self.tabOpAcHi.setTabText(self.tabOpAcHi.indexOf(self.tab_2), _translate("wdgDisReinvest", "Gains estimations"))
        self.tabAB.setTabText(self.tabAB.indexOf(self.tab_5), _translate("wdgDisReinvest", "After"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "Date"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Shares"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Price"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(3)
        item.setText(_translate("wdgDisReinvest", "Balance"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(4)
        item.setText(_translate("wdgDisReinvest", "Pending"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(5)
        item.setText(_translate("wdgDisReinvest", "% Year to Date"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(6)
        item.setText(_translate("wdgDisReinvest", "% APR"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(7)
        item.setText(_translate("wdgDisReinvest", "% Total"))
        item = self.tblInvestmentsActualDespuesAt.horizontalHeaderItem(8)
        item.setText(_translate("wdgDisReinvest", "Benchmark"))
        self.tabResultados_3.setTabText(self.tabResultados_3.indexOf(self.tab_12), _translate("wdgDisReinvest", "Investment situation"))
        self.tabAB.setTabText(self.tabAB.indexOf(self.tab_11), _translate("wdgDisReinvest", "After at"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "Date"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Shares"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Price"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(3)
        item.setText(_translate("wdgDisReinvest", "Balance"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(4)
        item.setText(_translate("wdgDisReinvest", "Pending"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(5)
        item.setText(_translate("wdgDisReinvest", "% Year to Date"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(6)
        item.setText(_translate("wdgDisReinvest", "% APR"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(7)
        item.setText(_translate("wdgDisReinvest", "% Total"))
        item = self.tblInvestmentsActualAntesAt.horizontalHeaderItem(8)
        item.setText(_translate("wdgDisReinvest", "Benchmark"))
        self.tabResultados_2.setTabText(self.tabResultados_2.indexOf(self.tab_7), _translate("wdgDisReinvest", "Investment situation"))
        self.tabAB.setTabText(self.tabAB.indexOf(self.tab_3), _translate("wdgDisReinvest", "Before at"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "Date"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Shares"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Price"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(3)
        item.setText(_translate("wdgDisReinvest", "Balance"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(4)
        item.setText(_translate("wdgDisReinvest", "Pending"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(5)
        item.setText(_translate("wdgDisReinvest", "% Year to Date"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(6)
        item.setText(_translate("wdgDisReinvest", "% APR"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(7)
        item.setText(_translate("wdgDisReinvest", "% Total"))
        item = self.tblInvestmentsActualAntes.horizontalHeaderItem(8)
        item.setText(_translate("wdgDisReinvest", "Benchmark"))
        self.tabResultados.setTabText(self.tabResultados.indexOf(self.tab_4), _translate("wdgDisReinvest", "Investment situation"))
        item = self.tblGainsBefore.horizontalHeaderItem(0)
        item.setText(_translate("wdgDisReinvest", "% Gains"))
        item = self.tblGainsBefore.horizontalHeaderItem(1)
        item.setText(_translate("wdgDisReinvest", "Price"))
        item = self.tblGainsBefore.horizontalHeaderItem(2)
        item.setText(_translate("wdgDisReinvest", "Gains"))
        self.tabResultados.setTabText(self.tabResultados.indexOf(self.tab), _translate("wdgDisReinvest", "Gains estimations"))
        self.tabAB.setTabText(self.tabAB.indexOf(self.tab_6), _translate("wdgDisReinvest", "Before"))


from xulpymoney.ui.myqlineedit import myQLineEdit
from xulpymoney.ui.myqtablewidget import myQTableWidget
import xulpymoney.images.xulpymoney_rc



from PyQt5.QtWidgets import QDialog
from xulpymoney.ui.Ui_frmTransfer import Ui_frmTransfer

from xulpymoney.libxulpymoney import  Account
from xulpymoney.libxulpymoneyfunctions import qmessagebox

class frmTransfer(QDialog, Ui_frmTransfer):
    def __init__(self, mem, origen=None, destino=None,   parent=None):
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.mem=mem
        
        self.origen=origen
        self.destino=destino
        
        self.mem.data.accounts_active().qcombobox(self.cmbOrigen,  origen)
        self.mem.data.accounts_active().qcombobox(self.cmbDestino,  destino)
        self.wdgDT.show_microseconds(False)
        self.wdgDT.set(self.mem)


    def on_cmd_pressed(self):
        try:
            id_origen=int(self.cmbOrigen.itemData(self.cmbOrigen.currentIndex()))
            id_destino=int(self.cmbDestino.itemData(self.cmbDestino.currentIndex()))
            importe=abs(self.txtImporte.decimal())
            comision=abs(self.txtComision.decimal())
        except:
            qmessagebox(self.tr("Error adding data"))
            return            
        if id_origen==id_destino:
            qmessagebox(self.tr("Origin and destiny accounts can't be the same"))
            return 
            
        Account(self.mem).transferencia(self.wdgDT.datetime(),  self.mem.data.accounts_active().find_by_id(id_origen), self.mem.data.accounts_active().find_by_id(id_destino),  importe,  comision)
        self.mem.con.commit()##Para commit la transferencia   
        
        self.done(0)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgProductHistoricalChart.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgProductHistoricalChart(object):
    def setupUi(self, wdgProductHistoricalChart):
        wdgProductHistoricalChart.setObjectName("wdgProductHistoricalChart")
        wdgProductHistoricalChart.resize(1561, 89)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(wdgProductHistoricalChart)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(wdgProductHistoricalChart)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.cmbChartType = QtWidgets.QComboBox(wdgProductHistoricalChart)
        self.cmbChartType.setObjectName("cmbChartType")
        self.cmbChartType.addItem("")
        self.cmbChartType.addItem("")
        self.horizontalLayout_2.addWidget(self.cmbChartType)
        self.horizontalLayout_6.addLayout(self.horizontalLayout_2)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_3 = QtWidgets.QLabel(wdgProductHistoricalChart)
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_4.addWidget(self.label_3)
        self.cmbOHCLDuration = QtWidgets.QComboBox(wdgProductHistoricalChart)
        self.cmbOHCLDuration.setObjectName("cmbOHCLDuration")
        self.horizontalLayout_4.addWidget(self.cmbOHCLDuration)
        self.horizontalLayout_6.addLayout(self.horizontalLayout_4)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(wdgProductHistoricalChart)
        self.label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.cmdFromLeftMax = QtWidgets.QToolButton(wdgProductHistoricalChart)
        self.cmdFromLeftMax.setObjectName("cmdFromLeftMax")
        self.horizontalLayout.addWidget(self.cmdFromLeftMax)
        self.cmdFromLeft = QtWidgets.QToolButton(wdgProductHistoricalChart)
        self.cmdFromLeft.setObjectName("cmdFromLeft")
        self.horizontalLayout.addWidget(self.cmdFromLeft)
        self.dtFrom = QtWidgets.QDateEdit(wdgProductHistoricalChart)
        self.dtFrom.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.dtFrom.setCalendarPopup(True)
        self.dtFrom.setObjectName("dtFrom")
        self.horizontalLayout.addWidget(self.dtFrom)
        self.cmdFromRight = QtWidgets.QToolButton(wdgProductHistoricalChart)
        self.cmdFromRight.setObjectName("cmdFromRight")
        self.horizontalLayout.addWidget(self.cmdFromRight)
        self.cmdFromRightMax = QtWidgets.QToolButton(wdgProductHistoricalChart)
        self.cmdFromRightMax.setObjectName("cmdFromRightMax")
        self.horizontalLayout.addWidget(self.cmdFromRightMax)
        self.horizontalLayout_6.addLayout(self.horizontalLayout)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem2)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.chkSMA50 = QtWidgets.QCheckBox(wdgProductHistoricalChart)
        self.chkSMA50.setChecked(True)
        self.chkSMA50.setObjectName("chkSMA50")
        self.horizontalLayout_3.addWidget(self.chkSMA50)
        self.chkSMA200 = QtWidgets.QCheckBox(wdgProductHistoricalChart)
        self.chkSMA200.setChecked(True)
        self.chkSMA200.setObjectName("chkSMA200")
        self.horizontalLayout_3.addWidget(self.chkSMA200)
        self.chkMedian = QtWidgets.QCheckBox(wdgProductHistoricalChart)
        self.chkMedian.setObjectName("chkMedian")
        self.horizontalLayout_3.addWidget(self.chkMedian)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.line = QtWidgets.QFrame(wdgProductHistoricalChart)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout_3.addWidget(self.line)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.chkAdjustSplits = QtWidgets.QCheckBox(wdgProductHistoricalChart)
        self.chkAdjustSplits.setChecked(True)
        self.chkAdjustSplits.setObjectName("chkAdjustSplits")
        self.horizontalLayout_5.addWidget(self.chkAdjustSplits)
        self.chkAdjustDividends = QtWidgets.QCheckBox(wdgProductHistoricalChart)
        self.chkAdjustDividends.setObjectName("chkAdjustDividends")
        self.horizontalLayout_5.addWidget(self.chkAdjustDividends)
        self.verticalLayout_3.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_6.addLayout(self.verticalLayout_3)
        self.verticalLayout_2.addLayout(self.horizontalLayout_6)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.verticalLayout_2.addLayout(self.verticalLayout)
        self.horizontalLayout_7.addLayout(self.verticalLayout_2)
        self.actionProductReport = QtWidgets.QAction(wdgProductHistoricalChart)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/books.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductReport.setIcon(icon)
        self.actionProductReport.setObjectName("actionProductReport")
        self.actionSortTPCDiario = QtWidgets.QAction(wdgProductHistoricalChart)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/document-preview.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSortTPCDiario.setIcon(icon1)
        self.actionSortTPCDiario.setObjectName("actionSortTPCDiario")
        self.actionSortTPCAnual = QtWidgets.QAction(wdgProductHistoricalChart)
        self.actionSortTPCAnual.setIcon(icon1)
        self.actionSortTPCAnual.setObjectName("actionSortTPCAnual")
        self.actionSortName = QtWidgets.QAction(wdgProductHistoricalChart)
        self.actionSortName.setIcon(icon1)
        self.actionSortName.setObjectName("actionSortName")
        self.actionSortDividend = QtWidgets.QAction(wdgProductHistoricalChart)
        self.actionSortDividend.setIcon(icon1)
        self.actionSortDividend.setObjectName("actionSortDividend")
        self.actionSortHour = QtWidgets.QAction(wdgProductHistoricalChart)
        self.actionSortHour.setIcon(icon1)
        self.actionSortHour.setObjectName("actionSortHour")
        self.actionIbex35 = QtWidgets.QAction(wdgProductHistoricalChart)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/countries/spain.gif"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionIbex35.setIcon(icon2)
        self.actionIbex35.setObjectName("actionIbex35")
        self.actionProductNew = QtWidgets.QAction(wdgProductHistoricalChart)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/xulpymoney/add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductNew.setIcon(icon3)
        self.actionProductNew.setObjectName("actionProductNew")
        self.actionProductDelete = QtWidgets.QAction(wdgProductHistoricalChart)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/xulpymoney/list-remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductDelete.setIcon(icon4)
        self.actionProductDelete.setObjectName("actionProductDelete")
        self.actionFavorites = QtWidgets.QAction(wdgProductHistoricalChart)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/xulpymoney/star.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFavorites.setIcon(icon5)
        self.actionFavorites.setObjectName("actionFavorites")
        self.actionMergeCodes = QtWidgets.QAction(wdgProductHistoricalChart)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/cakes.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionMergeCodes.setIcon(icon6)
        self.actionMergeCodes.setObjectName("actionMergeCodes")
        self.actionQuoteNew = QtWidgets.QAction(wdgProductHistoricalChart)
        self.actionQuoteNew.setIcon(icon3)
        self.actionQuoteNew.setObjectName("actionQuoteNew")
        self.actionEstimationDPSNew = QtWidgets.QAction(wdgProductHistoricalChart)
        self.actionEstimationDPSNew.setIcon(icon3)
        self.actionEstimationDPSNew.setObjectName("actionEstimationDPSNew")
        self.actionPurge = QtWidgets.QAction(wdgProductHistoricalChart)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/xulpymoney/tools-wizard.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPurge.setIcon(icon7)
        self.actionPurge.setObjectName("actionPurge")
        self.actionPurchaseGraphic = QtWidgets.QAction(wdgProductHistoricalChart)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/xulpymoney/report.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPurchaseGraphic.setIcon(icon8)
        self.actionPurchaseGraphic.setObjectName("actionPurchaseGraphic")
        self.actionProductPriceLastRemove = QtWidgets.QAction(wdgProductHistoricalChart)
        self.actionProductPriceLastRemove.setIcon(icon4)
        self.actionProductPriceLastRemove.setObjectName("actionProductPriceLastRemove")

        self.retranslateUi(wdgProductHistoricalChart)
        self.cmbChartType.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(wdgProductHistoricalChart)

    def retranslateUi(self, wdgProductHistoricalChart):
        _translate = QtCore.QCoreApplication.translate
        self.label_2.setText(_translate("wdgProductHistoricalChart", "Chart type"))
        self.cmbChartType.setItemText(0, _translate("wdgProductHistoricalChart", "Lines"))
        self.cmbChartType.setItemText(1, _translate("wdgProductHistoricalChart", "Candles"))
        self.label_3.setText(_translate("wdgProductHistoricalChart", "Select time range"))
        self.label.setText(_translate("wdgProductHistoricalChart", "Show from selected date"))
        self.cmdFromLeftMax.setText(_translate("wdgProductHistoricalChart", "<<"))
        self.cmdFromLeft.setText(_translate("wdgProductHistoricalChart", "<"))
        self.dtFrom.setDisplayFormat(_translate("wdgProductHistoricalChart", "yyyy-MM-dd"))
        self.cmdFromRight.setText(_translate("wdgProductHistoricalChart", ">"))
        self.cmdFromRightMax.setText(_translate("wdgProductHistoricalChart", ">>"))
        self.chkSMA50.setText(_translate("wdgProductHistoricalChart", "SMA50"))
        self.chkSMA200.setText(_translate("wdgProductHistoricalChart", "SMA200"))
        self.chkMedian.setText(_translate("wdgProductHistoricalChart", "Median"))
        self.chkAdjustSplits.setText(_translate("wdgProductHistoricalChart", "Adjust splits"))
        self.chkAdjustDividends.setText(_translate("wdgProductHistoricalChart", "Adjust splits and dividends"))
        self.actionProductReport.setText(_translate("wdgProductHistoricalChart", "Product report"))
        self.actionProductReport.setToolTip(_translate("wdgProductHistoricalChart", "Product report"))
        self.actionSortTPCDiario.setText(_translate("wdgProductHistoricalChart", "% Daily"))
        self.actionSortTPCDiario.setToolTip(_translate("wdgProductHistoricalChart", "% Daily"))
        self.actionSortTPCAnual.setText(_translate("wdgProductHistoricalChart", "% Annual"))
        self.actionSortTPCAnual.setToolTip(_translate("wdgProductHistoricalChart", "% Annual"))
        self.actionSortName.setText(_translate("wdgProductHistoricalChart", "Name"))
        self.actionSortName.setToolTip(_translate("wdgProductHistoricalChart", "Name"))
        self.actionSortDividend.setText(_translate("wdgProductHistoricalChart", "Dividend"))
        self.actionSortDividend.setToolTip(_translate("wdgProductHistoricalChart", "Dividend"))
        self.actionSortHour.setText(_translate("wdgProductHistoricalChart", "Hour"))
        self.actionSortHour.setToolTip(_translate("wdgProductHistoricalChart", "Hour"))
        self.actionIbex35.setText(_translate("wdgProductHistoricalChart", "Ibex 35"))
        self.actionProductNew.setText(_translate("wdgProductHistoricalChart", "New product"))
        self.actionProductNew.setToolTip(_translate("wdgProductHistoricalChart", "New user product"))
        self.actionProductDelete.setText(_translate("wdgProductHistoricalChart", "Delete product"))
        self.actionProductDelete.setToolTip(_translate("wdgProductHistoricalChart", "Delete user product"))
        self.actionFavorites.setText(_translate("wdgProductHistoricalChart", "Add to favorites"))
        self.actionFavorites.setToolTip(_translate("wdgProductHistoricalChart", "Add to favorites"))
        self.actionMergeCodes.setText(_translate("wdgProductHistoricalChart", "Merge selected codes"))
        self.actionMergeCodes.setToolTip(_translate("wdgProductHistoricalChart", "Merge selected codes"))
        self.actionQuoteNew.setText(_translate("wdgProductHistoricalChart", "New price"))
        self.actionQuoteNew.setToolTip(_translate("wdgProductHistoricalChart", "New price"))
        self.actionEstimationDPSNew.setText(_translate("wdgProductHistoricalChart", "New DPS estimation"))
        self.actionEstimationDPSNew.setToolTip(_translate("wdgProductHistoricalChart", "New Dividend per share estimation"))
        self.actionPurge.setText(_translate("wdgProductHistoricalChart", "Purge investment"))
        self.actionPurge.setToolTip(_translate("wdgProductHistoricalChart", "Deletes quotes innecesary. Leaves open, high, low and close quotes."))
        self.actionPurchaseGraphic.setText(_translate("wdgProductHistoricalChart", "Show purchase graphic"))
        self.actionPurchaseGraphic.setToolTip(_translate("wdgProductHistoricalChart", "Show purchase graphic"))
        self.actionProductPriceLastRemove.setText(_translate("wdgProductHistoricalChart", "Remove last product price"))
        self.actionProductPriceLastRemove.setToolTip(_translate("wdgProductHistoricalChart", "Remove last product price"))


import xulpymoney.images.xulpymoney_rc



from PyQt5.QtWidgets import QWidget,  QLabel, QHBoxLayout, QToolButton, QSizePolicy, QSpacerItem
from PyQt5.QtCore import pyqtSignal, Qt
from PyQt5.QtGui import QIcon, QPixmap
from xulpymoney.ui.myqlineedit import myQLineEdit
from decimal import Decimal

class wdgTwoCurrencyLineEdit(QWidget):
    factorChanged=pyqtSignal(Decimal)#Se usa para cargar datos de ordenes en los datos de este formulario
    textChanged=pyqtSignal()
    def __init__(self, parent):
        QWidget.__init__(self, parent)
        self.horizontalLayout = QHBoxLayout(self)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)

        self.label = QLabel(self)
        self.label.setText(self.tr("Select a product"))
        self.horizontalLayout.addWidget(self.label)

        spacerItem=QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)

        self.txtA=myQLineEdit(self)
        self.txtA.setAlignment(Qt.AlignRight|Qt.AlignTrailing|Qt.AlignVCenter)
        self.txtA.setToolTip(self.tr("Press the search button"))
        self.txtA.setText(0)
        self.horizontalLayout.addWidget(self.txtA)
    
        self.lblCurrencyA=QLabel(self)
        self.horizontalLayout.addWidget(self.lblCurrencyA)          
        
        self.cmd= QToolButton(self)               
        icon = QIcon()
        icon.addPixmap(QPixmap(":/xulpymoney/transfer.png"), QIcon.Normal, QIcon.Off)
        self.cmd.setIcon(icon)                      
        self.cmd.released.connect(self.on_cmd_released)        
        self.horizontalLayout.addWidget(self.cmd)          
        self.cmd.hide() 
        
        self.txtB=myQLineEdit(self)
        self.txtB.setAlignment(Qt.AlignRight|Qt.AlignTrailing|Qt.AlignVCenter)               
        self.txtB.setToolTip(self.tr("Press the search button"))
        self.txtB.setText(0)
        self.horizontalLayout.addWidget(self.txtB)             

        self.lblCurrencyB=QLabel(self)
        self.horizontalLayout.addWidget(self.lblCurrencyB)
        
        sizePolicy = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtA.sizePolicy().hasHeightForWidth())
        self.txtA.setSizePolicy(sizePolicy)
        sizePolicyb = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed)
        sizePolicyb.setHorizontalStretch(2)
        sizePolicyb.setVerticalStretch(0)
        sizePolicyb.setHeightForWidth(self.txtB.sizePolicy().hasHeightForWidth())
        self.txtB.setSizePolicy(sizePolicy)
        self.setLabelSize(200)
        self.factormode=False
        
    def setLabelSize(self, size):
        """
            Sets the label size
        """
        self.label.setFixedWidth(size)

    def setLabel(self, text):
        self.label.setText(text)
        
    def setFactorMode(self, boolean):
        """
            Este widget esta en factor mode y puede editar ambos textos, el resultado es un factor, que podrá ser 
            usado en otros widgets con setNewFactor
        """
        self.factormode=boolean
        if boolean==True:
            self.cmd.show()
            self.setTextA(1)
            self.setTextB(self.factor)
        else:
            self.cmd.hide()
    
    def on_cmd_released(self):
        self.txtA.textChanged.disconnect()
        self.txtB.textChanged.disconnect()
        tmp=self.txtA.decimal()
        self.txtA.setText(Decimal(1)/self.txtB.decimal())
        self.txtB.setText(Decimal(1)/tmp)
        self.txtA.textChanged.connect(self.on_txtA_textChanged)
        self.txtB.textChanged.connect(self.on_txtB_textChanged)
    
    
    def set(self, mem, currencya,  currencyb,  factor):
        """Investement is used to set investment pointer. It's usefull to see investment data in product report
        factor is to mul A to get b"""
        self.mem=mem       
        self.factor=factor
        self.currencya=currencya
        self.currencyb=currencyb

        if self.currencya==self.currencyb:
            self.lblCurrencyB.hide()
            self.txtB.hide()

        self.lblCurrencyA.setText(self.currencya.symbol+" ")   
        self.lblCurrencyB.setText(self.currencyb.symbol)

        self.txtA.textChanged.disconnect()
        self.txtB.textChanged.disconnect()
        self.txtB.setText(self.txtA.decimal()*factor)
        self.textChanged.emit()
        self.txtA.textChanged.connect(self.on_txtA_textChanged)
        self.txtB.textChanged.connect(self.on_txtB_textChanged)

    def isValid(self):
        if self.txtA.isValid() and self.txtB.isValid():
            return True
        return False

    def setTextA(self, text):
        self.txtA.setText(text)

    def setTextB(self, text):
        self.txtB.setText(text)

    def decimalA(self):
        return self.txtA.decimal()

    def decimalB(self):
        return self.txtB.decimal()

    def on_txtA_textChanged(self, text):
        myQLineEdit.on_textChanged(self.txtA, text)
        if self.txtA.isValid():
            if self.factormode==True:
                if self.txtB.decimal()==Decimal(0):
                    return
                self.factor=self.txtA.decimal()/self.txtB.decimal()
                self.factorChanged.emit(self.factor)
            else:
                self.txtB.textChanged.disconnect()
                self.txtB.setText(self.txtA.decimal()*self.factor)
                self.txtB.textChanged.connect(self.on_txtB_textChanged)
        self.textChanged.emit()

    def on_txtB_textChanged(self, text):
        myQLineEdit.on_textChanged(self.txtB, text)
        if self.txtB.isValid():
            if self.factormode==True:
                if self.txtA.decimal()==Decimal(0):
                    return
                self.factor=self.txtB.decimal()/self.txtA.decimal()
                self.factorChanged.emit(self.factor)
            else:
                self.txtA.textChanged.disconnect()
                self.txtA.setText(self.txtB.decimal()/self.factor)
                self.txtA.textChanged.connect(self.on_txtA_textChanged)
        self.textChanged.emit()

    def setReadOnly(self, boolean):
        self.txtA.setReadOnly(boolean)
        self.txtB.setReadOnly(boolean)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgInvestments.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgInvestments(object):
    def setupUi(self, wdgInvestments):
        wdgInvestments.setObjectName("wdgInvestments")
        wdgInvestments.resize(754, 525)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(wdgInvestments)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lbl = QtWidgets.QLabel(wdgInvestments)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lbl.setFont(font)
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout.addWidget(self.lbl)
        self.chkInactivas = QtWidgets.QCheckBox(wdgInvestments)
        self.chkInactivas.setObjectName("chkInactivas")
        self.verticalLayout.addWidget(self.chkInactivas)
        self.tblInvestments = myQTableWidget(wdgInvestments)
        self.tblInvestments.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblInvestments.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tblInvestments.setAlternatingRowColors(True)
        self.tblInvestments.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblInvestments.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblInvestments.setObjectName("tblInvestments")
        self.tblInvestments.setColumnCount(9)
        self.tblInvestments.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblInvestments.setHorizontalHeaderItem(8, item)
        self.tblInvestments.verticalHeader().setVisible(False)
        self.verticalLayout.addWidget(self.tblInvestments)
        self.verticalLayout_2.addLayout(self.verticalLayout)
        self.wdgIBM = QtWidgets.QWidget(wdgInvestments)
        self.wdgIBM.setObjectName("wdgIBM")
        self.verticalLayout_2.addWidget(self.wdgIBM)
        self.verticalLayout_3.addLayout(self.verticalLayout_2)
        self.lblTotal = QtWidgets.QLabel(wdgInvestments)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setBold(True)
        font.setWeight(75)
        self.lblTotal.setFont(font)
        self.lblTotal.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTotal.setWordWrap(True)
        self.lblTotal.setObjectName("lblTotal")
        self.verticalLayout_3.addWidget(self.lblTotal)
        self.actionInvestmentAdd = QtWidgets.QAction(wdgInvestments)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestmentAdd.setIcon(icon)
        self.actionInvestmentAdd.setObjectName("actionInvestmentAdd")
        self.actionInvestmentReport = QtWidgets.QAction(wdgInvestments)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/bundle.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestmentReport.setIcon(icon1)
        self.actionInvestmentReport.setObjectName("actionInvestmentReport")
        self.actionSortTPCDiario = QtWidgets.QAction(wdgInvestments)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpmoney/document-preview.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSortTPCDiario.setIcon(icon2)
        self.actionSortTPCDiario.setObjectName("actionSortTPCDiario")
        self.actionSortTPCVenta = QtWidgets.QAction(wdgInvestments)
        self.actionSortTPCVenta.setIcon(icon2)
        self.actionSortTPCVenta.setObjectName("actionSortTPCVenta")
        self.actionSortTPC = QtWidgets.QAction(wdgInvestments)
        self.actionSortTPC.setIcon(icon2)
        self.actionSortTPC.setObjectName("actionSortTPC")
        self.actionSortName = QtWidgets.QAction(wdgInvestments)
        self.actionSortName.setIcon(icon2)
        self.actionSortName.setObjectName("actionSortName")
        self.actionSortHour = QtWidgets.QAction(wdgInvestments)
        self.actionSortHour.setIcon(icon2)
        self.actionSortHour.setObjectName("actionSortHour")
        self.actionActive = QtWidgets.QAction(wdgInvestments)
        self.actionActive.setObjectName("actionActive")
        self.actionProduct = QtWidgets.QAction(wdgInvestments)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/xulpymoney/books.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProduct.setIcon(icon3)
        self.actionProduct.setObjectName("actionProduct")
        self.actionProductPrice = QtWidgets.QAction(wdgInvestments)
        self.actionProductPrice.setIcon(icon)
        self.actionProductPrice.setObjectName("actionProductPrice")
        self.actionInvestmentDelete = QtWidgets.QAction(wdgInvestments)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/xulpymoney/list-remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionInvestmentDelete.setIcon(icon4)
        self.actionInvestmentDelete.setObjectName("actionInvestmentDelete")
        self.actionProductPriceLastRemove = QtWidgets.QAction(wdgInvestments)
        self.actionProductPriceLastRemove.setIcon(icon4)
        self.actionProductPriceLastRemove.setObjectName("actionProductPriceLastRemove")
        self.actionSameProduct = QtWidgets.QAction(wdgInvestments)
        self.actionSameProduct.setIcon(icon1)
        self.actionSameProduct.setObjectName("actionSameProduct")
        self.actionSameProductFIFO = QtWidgets.QAction(wdgInvestments)
        self.actionSameProductFIFO.setIcon(icon1)
        self.actionSameProductFIFO.setObjectName("actionSameProductFIFO")
        self.actionProductUpdate = QtWidgets.QAction(wdgInvestments)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/xulpymoney/transfer.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProductUpdate.setIcon(icon5)
        self.actionProductUpdate.setObjectName("actionProductUpdate")

        self.retranslateUi(wdgInvestments)
        QtCore.QMetaObject.connectSlotsByName(wdgInvestments)

    def retranslateUi(self, wdgInvestments):
        _translate = QtCore.QCoreApplication.translate
        self.lbl.setText(_translate("wdgInvestments", "Investments list"))
        self.chkInactivas.setText(_translate("wdgInvestments", "Show inactive investments"))
        item = self.tblInvestments.horizontalHeaderItem(0)
        item.setText(_translate("wdgInvestments", "Investment"))
        item = self.tblInvestments.horizontalHeaderItem(1)
        item.setText(_translate("wdgInvestments", "Last datetime"))
        item = self.tblInvestments.horizontalHeaderItem(2)
        item.setText(_translate("wdgInvestments", "Last value"))
        item = self.tblInvestments.horizontalHeaderItem(3)
        item.setText(_translate("wdgInvestments", "Daily difference"))
        item = self.tblInvestments.horizontalHeaderItem(4)
        item.setText(_translate("wdgInvestments", "% Intraday"))
        item = self.tblInvestments.horizontalHeaderItem(5)
        item.setText(_translate("wdgInvestments", "Balance"))
        item = self.tblInvestments.horizontalHeaderItem(6)
        item.setText(_translate("wdgInvestments", "Pending"))
        item = self.tblInvestments.horizontalHeaderItem(7)
        item.setText(_translate("wdgInvestments", "% Invested"))
        item = self.tblInvestments.horizontalHeaderItem(8)
        item.setText(_translate("wdgInvestments", "% Selling point"))
        self.actionInvestmentAdd.setText(_translate("wdgInvestments", "New investment"))
        self.actionInvestmentAdd.setToolTip(_translate("wdgInvestments", "New investment"))
        self.actionInvestmentReport.setText(_translate("wdgInvestments", "Investment report"))
        self.actionInvestmentReport.setToolTip(_translate("wdgInvestments", "Investment report"))
        self.actionSortTPCDiario.setText(_translate("wdgInvestments", "% Daily"))
        self.actionSortTPCDiario.setToolTip(_translate("wdgInvestments", "% Daily"))
        self.actionSortTPCVenta.setText(_translate("wdgInvestments", "% Selling point"))
        self.actionSortTPCVenta.setToolTip(_translate("wdgInvestments", "% Selling point"))
        self.actionSortTPC.setText(_translate("wdgInvestments", "% Invested"))
        self.actionSortTPC.setToolTip(_translate("wdgInvestments", "% Invested"))
        self.actionSortName.setText(_translate("wdgInvestments", "Name"))
        self.actionSortName.setToolTip(_translate("wdgInvestments", "Name"))
        self.actionSortHour.setText(_translate("wdgInvestments", "Time"))
        self.actionSortHour.setToolTip(_translate("wdgInvestments", "Time"))
        self.actionActive.setText(_translate("wdgInvestments", "Is it active?"))
        self.actionActive.setToolTip(_translate("wdgInvestments", "Is it active?"))
        self.actionProduct.setText(_translate("wdgInvestments", "Product report"))
        self.actionProduct.setToolTip(_translate("wdgInvestments", "Product report"))
        self.actionProductPrice.setText(_translate("wdgInvestments", "Add product price"))
        self.actionProductPrice.setToolTip(_translate("wdgInvestments", "Add product price"))
        self.actionInvestmentDelete.setText(_translate("wdgInvestments", "Delete investment"))
        self.actionInvestmentDelete.setToolTip(_translate("wdgInvestments", "Delete investment"))
        self.actionProductPriceLastRemove.setText(_translate("wdgInvestments", "Remove last product price"))
        self.actionProductPriceLastRemove.setToolTip(_translate("wdgInvestments", "Remove last product price"))
        self.actionSameProduct.setText(_translate("wdgInvestments", "Same product Investments merging current operations"))
        self.actionSameProduct.setToolTip(_translate("wdgInvestments", "Same product Investments merging current operations"))
        self.actionSameProductFIFO.setText(_translate("wdgInvestments", "Same product Investments merging operations"))
        self.actionSameProductFIFO.setToolTip(_translate("wdgInvestments", "Same product Investments merging operations"))
        self.actionProductUpdate.setText(_translate("wdgInvestments", "Update product"))
        self.actionProductUpdate.setToolTip(_translate("wdgInvestments", "Update product"))


from xulpymoney.ui.myqtablewidget import myQTableWidget
import xulpymoney.images.xulpymoney_rc
